<?php
/*******************************************************************
 *			
 * 			Fichier			:	functions.stats.php 
 * 			Cr le			:	22 octobre 2002 
 * 			Dernire modif	:	14 mai 2003 
 * 			Email			:	wascripts@phpcodeur.net 
 * 
 * 				 Copyright 2002-2003 PHPcodeur
 * 
 *******************************************************************/

/*******************************************************************
 *  This program is free software; you can redistribute it and/or 
 * 	modify it under the terms of the GNU General Public License as 
 * 	published by the Free Software Foundation; either version 2 of 
 *  the License, or (at your option) any later version. 
 *******************************************************************/


if( !defined('FUNCTIONS_STATS_INC') )
{

define('FUNCTIONS_STATS_INC', 1); 

define('WA_STATS_PATH', $waroot . 'stats/', true); 

@chmod(wa_stats_path, 0775); 

/*
 * rvb_color()
 * 
 * Conversation de couleur hexadcimale  couleur rvb
 * 
 * @param $im (resource)	: Id de ressource de l'image
 * @param $color (string)	: Couleur en hexadcimal
 * 
 * @return integer
 */
function rvb_color($im, $color)
{
	$color = strtoupper($color); 
	preg_match('/^([A-F0-9]{2})([A-F0-9]{2})([A-F0-9]{2})$/', $color, $color_parts); 
	
	return imagecolorallocate($im, hexdec($color_parts[1]), hexdec($color_parts[2]), hexdec($color_parts[3])); 
}

/*
 * xy_arc()
 * 
 * Calcule les coordonnes du rayon
 * 
 * @param $degre (float)		: Degr
 * @param $diametre (integer)	: Diamtre du cercle
 * 
 * @return array
 */
function xy_arc($degre, $diametre)
{
	$x_arc = (cos($degre * (pi() / 180.0)) * ($diametre / 2)); 
	$y_arc = (sin($degre * (pi() / 180.0)) * ($diametre / 2)); 
	
	return array($x_arc, $y_arc); 
}

//
// Cration des fichiers de stats
//


/*
 * create_stats()
 * 
 * Cr le fichier de statistiques pour le mois et l'anne donns
 * 
 * @param $listdata (array)	: Donnes de la liste concerne
 * @param $month (integer)	: Chiffre du mois
 * @param $year (integer)	: Chiffre de l'anne
 * 
 * @return boolean
 */
function create_stats($listdata, $month, $year)
{
	global $db, $nl_config; 
	
	if( $nl_config['disable_stats'] || !@extension_loaded('gd') )
	{
		return false; 
	}
	
	@set_time_limit(300); 
	
	$filename = date('Y_F', mktime(0, 0, 0, $month, 1, $year)) . '_list' . $listdata['liste_id'] . '.txt'; 
	
	if( $fw = @fopen(wa_stats_path . $filename, 'w') )
	{
		$stats = array(); 
		
		for( $day = 1, $i = 0; $day <= 31; $day++, $i++ )
		{
			if( checkdate($month, $day, $year) )
			{
				$stats[$i] = 0; 
				$min_time = mktime(0, 0, 0, $month, $day, $year); 
				$max_time = mktime(23, 59, 59, $month, $day, $year); 
				
				$sql = "SELECT COUNT(a.abo_id) AS num_abo 
					FROM " . ABONNES_TABLE . " AS a, " . ABO_LISTE_TABLE . " AS al 
					WHERE al.liste_id = " . $listdata['liste_id'] . " AND a.abo_id = al.abo_id 
					  AND a.abo_status = " . ABO_ACTIF . " 
					  AND a.abo_register_date BETWEEN $min_time AND $max_time"; 
				if( $result = $db->query($sql) )
				{
					$stats[$i] = $db->result($result, 0, 'num_abo'); 
				}
			}
		}
		
		$stats_str = implode("\n", $stats); 
		
		fwrite($fw, $stats_str); 
		fclose($fw); 
		
		return true; 
	}
	
	return false; 	
}

/*
 * update_stats()
 * 
 * Mise  jour des donnes pour les statistiques 
 * 
 * @param $listdata (array)	: Donnes de la liste concerne
 * 
 * @return boolean
 */
function update_stats($listdata)
{
	global $nl_config; 
	
	if( $nl_config['disable_stats'] || !@extension_loaded('gd') )
	{
		return false; 
	}
	
	$filename = date('Y_F') . '_list' . $listdata['liste_id'] . '.txt'; 
	
	if( !@file_exists(wa_stats_path . $filename) )
	{
		return create_stats($listdata, date('m'), date('Y')); 
	}
	else
	{
		if( $fp = @fopen(wa_stats_path . $filename, 'r') )
		{
			$stats = fread($fp, filesize(wa_stats_path . $filename)); 
			fclose($fp); 
			
			$stats = preg_replace("(\r(?!\n)|\r\n)", "\n", $stats); 
			$days  = array_map('intval', explode("\n", $stats)); 
			
			$offset = (date('j') - 1); 
			$days[$offset] += 1; 
			
			$new_stats = implode("\n", $days); 
			
			@fwrite(@fopen(wa_stats_path . $filename, 'w'), $new_stats); 
			
			return true; 
		}
		
		return false; 
	}
}

/*
 * remove_stats()
 * 
 * Suppression/dplacement de stats (lors de la suppression d'une liste) 
 * 
 * @param $liste_from (integer)		  : Id de la liste dont on supprime/dplace les stats
 * @param $liste_to (integer/boolean) : Id de la liste de destination ou boolean (dans ce cas, on supprime)
 * 
 * @return boolean
 */
function remove_stats($liste_from, $liste_to = false)
{
	global $nl_config; 
	
	if( $nl_config['disable_stats'] || !@extension_loaded('gd') )
	{
		return false; 
	}
	
	@set_time_limit(300); 
	
	$res = @opendir(wa_stats_path); 
	
	$old_stats = array(); 
	while( $file = @readdir($res) )
	{
		if( preg_match("/^([0-9]{4}_[a-zA-Z]+)_list$liste_from\.txt$/i", $file, $match) )
		{
			if( $liste_to && $fp = @fopen(wa_stats_path . $file, 'r') )
			{
				$contents = fread($fp, filesize(wa_stats_path . $file)); 
				$contents = preg_replace("(\r(?!\n)|\r\n)", "\n", $contents); 
				
				$old_stats[$match[1]] = explode("\n", $contents); 
				fclose($fp); 
			}
			
			@unlink(wa_stats_path . $file); 
		}
	}	
	@closedir($res); 
	
	if( $liste_to && count($old_stats) )
	{
		foreach( $old_stats AS $date => $num )
		{
			$filename = $date . '_list' . $liste_to . '.txt'; 
			
			if( $fp = @fopen(wa_stats_path . $filename, 'r') )
			{
				$contents = fread($fp, filesize(wa_stats_path . $filename)); 
				$contents = preg_replace("(\r(?!\n)|\r\n)", "\n", $contents); 				
				$stats	  = array_map('intval', explode("\n", $contents)); 
				$num	  = array_map('intval', $num); 
				
				for( $i = 0; $i < count($stats); $i++ )
				{
					$stats[$i] += $num[$i]; 
				}
				
				$new_stats = implode("\n", $stats); 
				
				@fwrite(@fopen(wa_stats_path . $filename, 'w'), $new_stats); 
			}
		}
	}
	
	return true; 
}

}
?>